pub struct LfoAutomaton { /* private fields */ }Expand description
An LFO automaton that generates periodic modulation signals.
Supports multiple waveform shapes, configurable frequency, amplitude, offset, pulse width, and random-walk rate.
Implementations
Sourceimpl LfoAutomaton
impl LfoAutomaton
Sourcepub fn new(
name: &str,
frequency: f64,
amplitude: f64,
offset: f64,
waveform: LfoWaveform,
) -> Self
pub fn new( name: &str, frequency: f64, amplitude: f64, offset: f64, waveform: LfoWaveform, ) -> Self
Create a new LFO automaton.
Sourcepub fn with_range(self, range: Range) -> Self
pub fn with_range(self, range: Range) -> Self
Set the output range.
Sourcepub fn with_pulse_width(self, width: f64) -> Self
pub fn with_pulse_width(self, width: f64) -> Self
Set the pulse width for the Pulse waveform (0.01 – 0.99).
Sourcepub fn with_walk_rate(self, rate: f64) -> Self
pub fn with_walk_rate(self, rate: f64) -> Self
Set the random-walk step rate.