NamedFunction

Type Alias NamedFunction 

pub type NamedFunction = Arc<dyn Fn(f64, &HashMap<String, f64>) -> f64 + Send + Sync>;
A named function that can be referenced from serialized MappingDef and ServoDef instead of a raw closure.

Each function takes an input value plus a parameter map and returns a mapped value.

Aliased Type

pub struct NamedFunction { /* private fields */ }