pub trait Sink<T, const BUF_SIZE: usize>: Node<T, BUF_SIZE>where
T: Transcendental,{
// Required method
fn consume(
&mut self,
clock: &ClockTick,
signal_inputs: &[&[T; BUF_SIZE]],
control_inputs: &[T],
clock_inputs: &[ClockTick],
feedback_inputs: &[&[T; BUF_SIZE]],
) -> Result<(), ProcessError>;
}Expand description
Active sink of signals
Sinks consume signal and send it to external destinations. They have no signal outputs, but may have control and clock ports.
Required Methods
Sourcefn consume(
&mut self,
clock: &ClockTick,
signal_inputs: &[&[T; BUF_SIZE]],
control_inputs: &[T],
clock_inputs: &[ClockTick],
feedback_inputs: &[&[T; BUF_SIZE]],
) -> Result<(), ProcessError>
fn consume( &mut self, clock: &ClockTick, signal_inputs: &[&[T; BUF_SIZE]], control_inputs: &[T], clock_inputs: &[ClockTick], feedback_inputs: &[&[T; BUF_SIZE]], ) -> Result<(), ProcessError>
Consume a block of signal
Arguments
clock- Current clock ticksignal_inputs- Signal input buffers (one per signal input)control_inputs- Control signal values (one per control input)clock_inputs- Clock signal values (one per clock input)feedback_inputs- Feedback values from previous blocks