pub struct ValueConverter { /* private fields */ }Expand description
Converts values between different scales using a specified transform.
Implementations
Sourceimpl ValueConverter
impl ValueConverter
Sourcepub fn new(
input_range: Range,
output_range: Range,
transform: Transform,
) -> Self
pub fn new( input_range: Range, output_range: Range, transform: Transform, ) -> Self
Create a new value converter.
Sourcepub fn convert(&self, value: f64) -> f64
pub fn convert(&self, value: f64) -> f64
Convert a value from the input range to the output range.
Sourcepub fn convert_inverse(&self, value: f64) -> f64
pub fn convert_inverse(&self, value: f64) -> f64
Convert a value in the reverse direction (approximate).