Module strategy

Module strategy 

Automaton control strategies

Automaton control strategies

Defines how an automaton affects a node parameter and how conflicts between automatic and manual control are resolved.

Enums

ConflictStrategy
Conflict resolution strategy between UI and automaton
ControlStrategy
How the automaton affects the target parameter
UiCommand
Command from UI to PortCombiner