Automaton control strategies
Automaton control strategies
Defines how an automaton affects a node parameter and how conflicts between automatic and manual control are resolved.
Enums
- Conflict
Strategy - Conflict resolution strategy between UI and automaton
- Control
Strategy - How the automaton affects the target parameter
- UiCommand
- Command from UI to PortCombiner