pub enum ConflictStrategy {
TouchOverride,
BasePlusModulation,
LastWriteWins,
}Expand description
Conflict resolution strategy between UI and automaton
Variants
TouchOverride
UI touch freezes the automaton for this port.
On SetBase, the automaton stops affecting the parameter.
On Release, the automaton resumes control.
BasePlusModulation
UI sets the base value, the automaton modulates around it.
The final value is computed using the control strategy formula combining the UI base value and automaton modulation.
LastWriteWins
The last writer to the queue wins.
UI and automaton write to the queue independently. The order of application is determined by the message order in the MpscQueue.