Утилиты и вспомогательные функции Utility functions and helpers for the patchbay.
Provides value converters, metronome timing, note-type conversion, test helpers, and test-signal generation.
Structs
- Event
Recorder - Records events for testing purposes.
- Metronome
- A metronome for synchronisation with BPM.
- Recorded
Event - A single recorded event.
- Test
Signal Generator - Generates test signals for verification and debugging.
- Test
Signal Params - Parameters for a test signal.
- Value
Converter - Converts values between different scales using a specified transform.
Enums
- Note
Type - A musical note type for duration calculations.
- Test
Signal Type - Type of test signal.
Functions
- freq_
to_ midi_ note - Convert a frequency in Hz to the nearest MIDI note number.
- midi_
note_ to_ freq - Convert a MIDI note number to frequency in Hz.
- midi_
to_ normalized - Convert a MIDI value (0–127) to a normalised float (0.0–1.0).
- normalized_
to_ midi - Convert a normalised float (0.0–1.0) to a MIDI value (0–127).
- note_
duration_ to_ seconds - Convert a note type to duration in seconds at the given BPM.